==> struts-6.7.0-all.zip: struts-6.7.0/src/core/src/test/java/org/apache/struts2/config/TestSettings.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.struts2.config;

import com.opensymphony.xwork2.util.location.Location;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;


/**
 * TestSettings
 *
 */
public class TestSettings implements Settings {

    /**
     * Get a named setting.
     *
     * @throws IllegalArgumentException if there is no settings parameter with the given name.
     */
    public String get(String aName) throws IllegalArgumentException {
        return aName;
    }

    /**
     * List setting names
     */
    public Iterator list() {
        List testList = new ArrayList();
        testList.add("123");
        testList.add("testValue");

        return testList.iterator();
    }

    public Location getLocation(String name) {
        return null;
    }
}

==> struts-7.0.0-all.zip: struts-7.0.0/src/core/src/test/java/org/apache/struts2/config/TestSettings.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.struts2.config;

import org.apache.struts2.util.location.Location;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;


/**
 * TestSettings
 *
 */
public class TestSettings implements Settings {

    /**
     * Get a named setting.
     *
     * @throws IllegalArgumentException if there is no settings parameter with the given name.
     */
    public String get(String aName) throws IllegalArgumentException {
        return aName;
    }

    /**
     * List setting names
     */
    public Iterator list() {
        List testList = new ArrayList();
        testList.add("123");
        testList.add("testValue");

        return testList.iterator();
    }

    public Location getLocation(String name) {
        return null;
    }
}
